// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package report

import (
	"LAPP_ACURA_MOM_BACKEND/global"
	"LAPP_ACURA_MOM_BACKEND/grmi"
	model "LAPP_ACURA_MOM_BACKEND/models/report"
	"LAPP_ACURA_MOM_BACKEND/web/middleware/jwts"
	"LAPP_ACURA_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterOneDashBoardHead(party router.Party, httpMethod string, path string, method func(*global.User, *model.DashBoardHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.DashBoardHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterIDOfDashBoardHead(party router.Party, httpMethod string, path string, method func(*global.User, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		dashboardId := ctx.Params().GetString("dashboardId")

		err = method(user, dashboardId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterInsertOneDashBoardHead(party router.Party, path string, method func(*global.User, *model.DashBoardHead) error) {

	RegisterOneDashBoardHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterDeleteOneDashBoardHead(party router.Party, path string, method func(*global.User, string) error) {

	RegisterIDOfDashBoardHead(party, "DELETE", path+"/{dashboardId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterSelectOneDashBoardHead(party router.Party, path string, method func(*global.User, string) (*model.DashBoardHead, error)) {

	party.Get(path+"/{dashboardId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		dashboardId := ctx.Params().GetString("dashboardId")
		result, err := method(user, dashboardId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterUpdateOneDashBoardHead(party router.Party, path string, method func(*global.User, *model.DashBoardHead) error) {

	RegisterOneDashBoardHead(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterMultiDashBoardHead(party router.Party, httpMethod string, path string, method func(*global.User, *[]model.DashBoardHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.DashBoardHead, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterInsertDashBoardHead(party router.Party, path string, method func(*global.User, *[]model.DashBoardHead) error) {

	RegisterMultiDashBoardHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterDeleteDashBoardHead(party router.Party, path string, method func(*global.User, *[]model.DashBoardHead) error) {

	RegisterMultiDashBoardHead(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterSelectDashBoardHead(party router.Party, path string, method func(*global.User, map[string]string) ([]model.DashBoardHead, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterQueryDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询DashBoardHead并分页的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterQueryDashBoardHead(party router.Party, path string, method func(*global.User, map[string]string) (grmi.PagingResult, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateDashBoardHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条DashBoardHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2022-01-06 11:05:20
 *
 ******************************************************************************/
func RegisterUpdateDashBoardHead(party router.Party, path string, method func(*global.User, *[]model.DashBoardHead) error) {

	RegisterMultiDashBoardHead(party, "PUT", path, method)
}
