// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package report

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	svr "LAPP_ACURA_MOM_BACKEND/services/report"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块report路由分组
	grmi.RegisterRouteMapping("/report", func(party router.Party) {

		// FilterDataInfo的路由组
		//filterdatainfo := party.Party("/filterdatainfo")
		// FilterDataInfo的服务实例
		//var serviceOfFilterDataInfo = svr.NewFilterDataInfoService()
		// FilterDataInfo插入一条
		// RegisterInsertOneFilterDataInfo(filterdatainfo, "/insertone", serviceOfFilterDataInfo.InsertOne)
		// FilterDataInfo插入多条
		// RegisterInsertFilterDataInfo(filterdatainfo, "/insert", serviceOfFilterDataInfo.Insert)
		// FilterDataInfo删除一条
		// RegisterDeleteOneFilterDataInfo(filterdatainfo, "/deleteone", serviceOfFilterDataInfo.DeleteOne)
		// FilterDataInfo删除多条
		// RegisterDeleteFilterDataInfo(filterdatainfo, "/delete", serviceOfFilterDataInfo.Delete)
		// FilterDataInfo查询多条
		//RegisterSelectFilterDataInfo(filterdatainfo, "/query", serviceOfFilterDataInfo.Select)
		// FilterDataInfo查询一条
		//RegisterSelectOneFilterDataInfo(filterdatainfo, "/get", serviceOfFilterDataInfo.SelectOne)
		// FilterDataInfo修改一条
		// RegisterUpdateOneFilterDataInfo(filterdatainfo, "/updateone", serviceOfFilterDataInfo.UpdateOne)
		// FilterDataInfo修改多条
		// RegisterUpdateFilterDataInfo(filterdatainfo, "/update", serviceOfFilterDataInfo.Update)
		// 弧焊机数据统计展示
		//RegisterGetArcDisplayData(filterdatainfo, "/display", serviceOfFilterDataInfo.GetDisplayData)

		// Display的路由组
		display := party.Party("/display")
		// Display的服务实例
		var serviceOfDisplay = svr.NewDisplayService()
		// Display插入一条
		// RegisterInsertOneDisplay(display, "/insertone", serviceOfDisplay.InsertOne)
		// Display插入多条
		// RegisterInsertDisplay(display, "/insert", serviceOfDisplay.Insert)
		// Display删除一条
		// RegisterDeleteOneDisplay(display, "/deleteone", serviceOfDisplay.DeleteOne)
		// Display删除多条
		// RegisterDeleteDisplay(display, "/delete", serviceOfDisplay.Delete)
		// Display查询多条
		RegisterSelectDisplay(display, "/query", serviceOfDisplay.Select)
		// Display查询一条
		RegisterSelectOneDisplay(display, "/get", serviceOfDisplay.SelectOne)
		// Display修改一条
		// RegisterUpdateOneDisplay(display, "/updateone", serviceOfDisplay.UpdateOne)
		// Display修改多条
		// RegisterUpdateDisplay(display, "/update", serviceOfDisplay.Update)

		// DisplayParam的路由组
		displayparam := party.Party("/displayparam")
		// DisplayParam的服务实例
		var serviceOfDisplayParam = svr.NewDisplayParamService()
		// DisplayParam插入一条
		// RegisterInsertOneDisplayParam(displayparam, "/insertone", serviceOfDisplayParam.InsertOne)
		// DisplayParam插入多条
		// RegisterInsertDisplayParam(displayparam, "/insert", serviceOfDisplayParam.Insert)
		// DisplayParam删除一条
		// RegisterDeleteOneDisplayParam(displayparam, "/deleteone", serviceOfDisplayParam.DeleteOne)
		// DisplayParam删除多条
		// RegisterDeleteDisplayParam(displayparam, "/delete", serviceOfDisplayParam.Delete)
		// DisplayParam查询多条
		RegisterSelectDisplayParam(displayparam, "/query", serviceOfDisplayParam.Select)
		// DisplayParam查询一条
		RegisterSelectOneDisplayParam(displayparam, "/get", serviceOfDisplayParam.SelectOne)
		// DisplayParam修改一条
		// RegisterUpdateOneDisplayParam(displayparam, "/updateone", serviceOfDisplayParam.UpdateOne)
		// DisplayParam修改多条
		// RegisterUpdateDisplayParam(displayparam, "/update", serviceOfDisplayParam.Update)

		// DashBoardHead的路由组
		dashboardhead := party.Party("/dashboardhead")
		// DashBoardHead的服务实例
		var serviceOfDashBoardHead = svr.NewDashBoardHeadService()
		// DashBoardHead插入一条
		// RegisterInsertOneDashBoardHead(dashboardhead, "/insertone", serviceOfDashBoardHead.InsertOne)
		// DashBoardHead插入多条
		// RegisterInsertDashBoardHead(dashboardhead, "/insert", serviceOfDashBoardHead.Insert)
		// DashBoardHead删除一条
		// RegisterDeleteOneDashBoardHead(dashboardhead, "/deleteone", serviceOfDashBoardHead.DeleteOne)
		// DashBoardHead删除多条
		// RegisterDeleteDashBoardHead(dashboardhead, "/delete", serviceOfDashBoardHead.Delete)
		// DashBoardHead查询多条
		RegisterSelectDashBoardHead(dashboardhead, "/selectlist", serviceOfDashBoardHead.Select)
		// DashBoardHead查询多条并分页
		RegisterQueryDashBoardHead(dashboardhead, "/query", serviceOfDashBoardHead.SelectAndPaging)
		// DashBoardHead查询一条
		RegisterSelectOneDashBoardHead(dashboardhead, "/selectone", serviceOfDashBoardHead.SelectOne)
		// DashBoardHead修改一条
		// RegisterUpdateOneDashBoardHead(dashboardhead, "/updateone", serviceOfDashBoardHead.UpdateOne)
		// DashBoardHead修改多条
		// RegisterUpdateDashBoardHead(dashboardhead, "/update", serviceOfDashBoardHead.Update)

		// DashBoardLst的路由组
		dashboardlst := party.Party("/dashboardlst")
		// DashBoardLst的服务实例
		var serviceOfDashBoardLst = svr.NewDashBoardLstService()
		// DashBoardLst插入一条
		// RegisterInsertOneDashBoardLst(dashboardlst, "/insertone", serviceOfDashBoardLst.InsertOne)
		// DashBoardLst插入多条
		// RegisterInsertDashBoardLst(dashboardlst, "/insert", serviceOfDashBoardLst.Insert)
		// DashBoardLst删除一条
		// RegisterDeleteOneDashBoardLst(dashboardlst, "/deleteone", serviceOfDashBoardLst.DeleteOne)
		// DashBoardLst删除多条
		// RegisterDeleteDashBoardLst(dashboardlst, "/delete", serviceOfDashBoardLst.Delete)
		// DashBoardLst查询多条
		RegisterSelectDashBoardLst(dashboardlst, "/selectlist", serviceOfDashBoardLst.Select)
		// DashBoardLst查询多条并分页
		RegisterQueryDashBoardLst(dashboardlst, "/query", serviceOfDashBoardLst.SelectAndPaging)
		// DashBoardLst查询一条
		RegisterSelectOneDashBoardLst(dashboardlst, "/selectone", serviceOfDashBoardLst.SelectOne)
		// DashBoardLst修改一条
		// RegisterUpdateOneDashBoardLst(dashboardlst, "/updateone", serviceOfDashBoardLst.UpdateOne)
		// DashBoardLst修改多条
		// RegisterUpdateDashBoardLst(dashboardlst, "/update", serviceOfDashBoardLst.Update)

		RegisterRouteMappingOfCustomizedQuery(party)
	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
